@@ -5,16 +5,22 @@ from livestreamer.plugin.api import http, validate
 from livestreamer.stream import RTMPStream
 
 SWF_URL = "http://www.gaminglive.tv/lib/flowplayer/flash/flowplayer.commercial-3.2.18.swf"
-CHANNELS_API_URL = "http://api.gaminglive.tv/channels/{0}"
+API_URL = "http://api.gaminglive.tv/{0}/{1}"
+VOD_RTMP_URL = "rtmp://gamingfs.fplive.net/gaming/{0}/"
 QUALITY_WEIGHTS = {
-    "live": 3,
+    "source": 5,
+    "live": 5,
+    "1080": 4,
+    "720": 3,
+    "480": 2,
     "medium": 2,
-    "low": 1,
+    "360": 1,
+    "low": 1
 }
 
 _url_re = re.compile("""
-    http(s)?://www\.gaminglive\.tv
-    /\#/channels/(?P<channel>[^/]+)
+    http(s)?://(\w+\.)?gaminglive\.tv
+    /(?P<type>channels|videos)/(?P<name>[^/]+)
 """, re.VERBOSE)
 _quality_re = re.compile("[^/]+-(?P<quality>[^/]+)")
 
@@ -30,6 +36,14 @@ _channel_schema = validate.Schema(
     validate.get("state")
 )
 
+_vod_schema = validate.Schema(
+    {
+        "name": validate.text,
+        "channel_slug": validate.text,
+        "title": validate.text,
+        "created_at": validate.transform(int)
+    },
+)
 
 class GamingLive(Plugin):
     @classmethod
@@ -51,28 +65,45 @@ class GamingLive(Plugin):
 
         return "live"
 
-    def _get_streams(self):
-        match = _url_re.match(self.url)
-        channel = match.group("channel")
+    def _create_rtmp_stream(self, rtmp, playpath, live):
+        return RTMPStream(self.session, {
+                    "rtmp": rtmp,
+                    "playpath": playpath,
+                    "pageUrl": self.url,
+                    "swfVfy": SWF_URL,
+                    "live": live
+                })
 
-        res = http.get(CHANNELS_API_URL.format(channel))
+    def _get_live_streams(self, name):
+        res = http.get(API_URL.format("channels", name))
         json = http.json(res, schema=_channel_schema)
         if not json:
             return
 
         streams = {}
         for quality in json["stream"]["qualities"]:
-            stream_name = self._get_quality(quality)
-            stream = RTMPStream(self.session, {
-                "rtmp": json["stream"]["rootUrl"],
-                "playpath": quality,
-                "pageUrl": self.url,
-                "swfVfy": SWF_URL,
-                "live": True
-            })
-            streams[stream_name] = stream
+            streams[self._get_quality(quality)] = self._create_rtmp_stream(json["stream"]["rootUrl"], quality, True)
 
         return streams
 
+    def _get_vod_streams(self, name):
+        res = http.get(API_URL.format("videos", name))
+        json = http.json(res, schema=_vod_schema)
+        if not json:
+            return
+
+        streams = {}
+        streams["source"] = self._create_rtmp_stream(VOD_RTMP_URL.format(json["channel_slug"]), json["name"], True)
+
+        return streams
+
+    def _get_streams(self):
+        match = _url_re.match(self.url)
+        type = match.group("type")
+
+        if type == "channels":
+            return self._get_live_streams(match.group("name"))
+        elif type == "videos":
+            return self._get_vod_streams(match.group("name"))
 
 __plugin__ = GamingLive
